@@ -3,6 +3,7 @@ mod use_before_unload;
 mod use_click_away;
 mod use_counter;
 mod use_debounce;
+mod use_debounce_state;
 mod use_default;
 mod use_drag;
 mod use_drop;
@@ -50,6 +51,7 @@ pub use use_before_unload::*;
 pub use use_click_away::*;
 pub use use_counter::*;
 pub use use_debounce::*;
+pub use use_debounce_state::*;
 pub use use_default::*;
 pub use use_drag::*;
 pub use use_drop::*;
